# INTRODUCTION

**iNotify Live Notifications For Drupal.**
iNotify provides the means to display live notifications based on custom events.

# HOW IT WORKS

The module provides a custom Notification entity that admins with permissions can customize its fields and display. Notifications can be created using a Custom Rules Action that is provided, you can trigger the action on any system event, and fill the fields with custom data. The module uses Mercure to automatically refresh the notifications view whenever it's available on display. The module also provides a notifications block to place within any region you want.

**_The module does not contain styles, only yhe basics. You will have to style the block and write CSS according to your design._**

# REQUIREMENTS

1.  [Rules](https://www.drupal.org/project/rules "Rules")

# OPTIONAL REQUIREMENTS

1.  [Mercure](https://www.drupal.org/project/mercure "Mercure")
2.  [Toastr](https://github.com/CodeSeven/toastr "Toastr")

# INSTALLATION

Open your terminal and download with composer.
` composer require drupal/inotify`

OR

1. Download the module to your DRUPAL_ROOT/modules directory,
   or where ever you install contrib modules on your site.
2. Go to Admin > Extend and enable the module.

# CONFIGURATION

1. Enable the module and create a rule to create a notification or create a notification programatically.

# MERCURE INTEGRATION

- ### To enable real time notification, Mercure module should be installed and configured

## INSTALLATION
1. Install Mercure Hub on your server, if not installed yet. https://mercure.rocks/docs/hub/install

2. Install the Mercure module: composer require drupal/mercure.

3. Configure Mercure module as in https://git.drupalcode.org/project/mercure/-/blob/master/README.md

4. Add Toastr library in libraries/toastr/build/toastr.min.js, libraries/toastr/build/toastr.min.css
- Adding Toastr via composer, follow guide in https://www.drupal.org/docs/develop/using-composer/using-composer-to-install-drupal-and-manage-dependencies#third-party-libraries
- composer require npm-asset/toastr

5. You are done, create a notification to test it or run this drush command (replace USERID with the uid):
  ```
  drush ev '
  $service = \Drupal::service("mercure.hub.default");

  $update = new Symfony\Component\Mercure\Update(
              "inotify_mercure_user_notifications_USERID",
              json_encode(["message" => "OutOfStock","title" => "Product"])
          );
  $service->publish($update);'
  ```


#GETTING IT TO WORK

1.  After installation, make sure you do a ll the required configurations.
2.  Go to **admin/config/workflow/rules** and create a new reaction rule based on whatever event you want.
3.  After configuring your reaction rule, make sure to add **Create Notification** to your actions list. you can add the title and description values within the action. When you are done, save you rule.
4.  Go to your theme block layout and place the **Notifications Block** within the intended region (usually the header), then save.
5.  Now you should see the block displayed in the region.To test it out, you can trigger you reaction rule and see the notification block automatically refreshing and displaying the new notification.

#ADVANCED USAGE & CUSOMIZATION

- ### Customizing the Notification Entity

  The Notification entity provided is basically like any other content entity within Drupal. You can visit **admin/structure/inotify_notification_settings** and add or customize fields, alongside changing form display and content display modes, just do with it what you do with nodes.

- ### Customizing the Notification View

  TODO

- ### Creating notification programmatically

  Just create the inotify_notification entity programmatically
  ```
  $notification = \Drupal::entityTypeManager()->getStorage('inotify_notification')->create({
    'title' => 'Test',
    'description' => 'Test description',
    'target_link' => 'TEST TARGET LINK',
    'uid' => 1, // The user that should recieve this notification.
  });
  $notification->save();
  ```

- ### Overriding Notifications Block Template

  For modifing the block template, copy the template file
  **templates/block--views-block--notifications-notifications-block.html.twig**
  to your custome theme or custom module. You can modify the structure of the block display, just make sure to put your HTML within the {% block content %} tags, and never forget to use {{ content }} to render the actual view.

- ### Overriding Notifications Entity Template

  For modifing the Notification template, copy the template file
  **templates/inotify-notification.html.twig**
  to your custome theme or custom module. You can modify the structure of the notification display based on the variable **view_mode** in case you created a view mode for the entity, you can also use the **content** variable just like any other content entity. You can always add more variables to the template using the hook **template_preprocess_inotify_notification**, go to **inotify.module** file to see how it's implemented.

- ### Custom CSS Styling
  The included CSS file only provides a basic style to make it possible to you to see how the module works. You should have your own CSS file within your theme or custom module, just style the block like any other element within your theme.

# MAINTAINERS

**Yasser Samman**
https://jo.linkedin.com/in/yasseralsamman
y.samman@codersme.com

**Anas Mawlawi**
https://jo.linkedin.com/in/anasmawlawi
a.mawlawi@codersme.com
